@@ -1,5 +1,4 @@
 ### R code from vignette source 'BoolNet_package_vignette.Snw'
-### Encoding: UTF-8
 
 ###################################################
 ### code chunk number 1: BoolNet_package_vignette.Snw:81-82 (eval = FALSE)
@@ -52,23 +51,13 @@ net
 
 
 ###################################################
-### code chunk number 9: BoolNet_package_vignette.Snw:253-258
-###################################################
-pdf("wiring1.pdf") 
-par(mar = c(1, 1, 1, 1))
-set.seed(333)
-plotNetworkWiring(net)
-dev.off()
-
-
-###################################################
-### code chunk number 10: BoolNet_package_vignette.Snw:260-261 (eval = FALSE)
+### code chunk number 9: BoolNet_package_vignette.Snw:253-254 (eval = FALSE)
 ###################################################
 ## plotNetworkWiring(net)
 
 
 ###################################################
-### code chunk number 11: BoolNet_package_vignette.Snw:275-279
+### code chunk number 10: BoolNet_package_vignette.Snw:268-272
 ###################################################
 net <- reconstructNetwork(binSeries$binarizedMeasurements, 
                           method="bestfit", 
@@ -77,37 +66,30 @@ net <- reconstructNetwork(binSeries$binarizedMeasurements,
 
 
 ###################################################
-### code chunk number 12: BoolNet_package_vignette.Snw:281-286
-###################################################
-pdf("wiring2.pdf") 
-par(mar = c(1, 1, 1, 1))
-set.seed(442)
-plotNetworkWiring(net)
-dev.off()
-
-
-###################################################
-### code chunk number 13: BoolNet_package_vignette.Snw:294-297
+### code chunk number 11: BoolNet_package_vignette.Snw:281-287
 ###################################################
 net <- reconstructNetwork(binSeries$binarizedMeasurements, 
 method="bestfit", maxK=4)
-singleNet <- chooseNetwork(net, c(1,2,3,2))
+functionIndices <- c(1,2,3,2) #select function index for each regulatory component
+dontCareDefaults <- lapply(seq_along(net$interactions), function(idx) rep(F, sum(net$interactions[[idx]][[functionIndices[idx]]]$func == -1))) #determine number of don't care values for each selected function and set them to 0
+names(dontCareDefaults) <- net$genes
+singleNet <- chooseNetwork(net, functionIndices, dontCareValues = dontCareDefaults)
 
 
 ###################################################
-### code chunk number 14: BoolNet_package_vignette.Snw:300-301
+### code chunk number 12: BoolNet_package_vignette.Snw:290-291
 ###################################################
 singleNet
 
 
 ###################################################
-### code chunk number 15: BoolNet_package_vignette.Snw:307-308
+### code chunk number 13: BoolNet_package_vignette.Snw:297-298
 ###################################################
 set.seed(3176)
 
 
 ###################################################
-### code chunk number 16: BoolNet_package_vignette.Snw:310-314
+### code chunk number 14: BoolNet_package_vignette.Snw:300-304
 ###################################################
 series <- generateTimeSeries(cellcycle, 
                              numSeries=100, 
@@ -116,7 +98,7 @@ series <- generateTimeSeries(cellcycle,
 
 
 ###################################################
-### code chunk number 17: BoolNet_package_vignette.Snw:319-322
+### code chunk number 15: BoolNet_package_vignette.Snw:309-312
 ###################################################
 binSeries <- binarizeTimeSeries(series, method="kmeans")
 net <- reconstructNetwork(binSeries$binarizedMeasurements, method="bestfit")
@@ -124,13 +106,13 @@ net
 
 
 ###################################################
-### code chunk number 18: BoolNet_package_vignette.Snw:328-329
+### code chunk number 16: BoolNet_package_vignette.Snw:318-319
 ###################################################
 set.seed(4463)
 
 
 ###################################################
-### code chunk number 19: BoolNet_package_vignette.Snw:331-336
+### code chunk number 17: BoolNet_package_vignette.Snw:321-326
 ###################################################
 series <- generateTimeSeries(cellcycle, 
                              numSeries=10, 
@@ -140,13 +122,13 @@ series <- generateTimeSeries(cellcycle,
 
 
 ###################################################
-### code chunk number 20: <
+### code chunk number 18: <
 ###################################################
 series$perturbations
 
 
 ###################################################
-### code chunk number 21: BoolNet_package_vignette.Snw:347-351
+### code chunk number 19: BoolNet_package_vignette.Snw:337-341
 ###################################################
 perturbations <- series$perturbations
 series$perturbations <- NULL
@@ -155,7 +137,7 @@ binSeries <- binarizeTimeSeries(series, method="kmeans")
 
 
 ###################################################
-### code chunk number 22: BoolNet_package_vignette.Snw:354-358
+### code chunk number 20: BoolNet_package_vignette.Snw:344-348
 ###################################################
 net <- reconstructNetwork(binSeries$binarizedMeasurements, 
                           method="bestfit", 
@@ -164,31 +146,31 @@ net
 
 
 ###################################################
-### code chunk number 23: BoolNet_package_vignette.Snw:367-368
+### code chunk number 21: BoolNet_package_vignette.Snw:357-358
 ###################################################
 net <- generateRandomNKNetwork(n=10, k=3)
 
 
 ###################################################
-### code chunk number 24: BoolNet_package_vignette.Snw:371-372
+### code chunk number 22: BoolNet_package_vignette.Snw:361-362
 ###################################################
 net <- generateRandomNKNetwork(n=10, k=c(1,2,3,1,3,2,3,2,1,1))
 
 
 ###################################################
-### code chunk number 25: BoolNet_package_vignette.Snw:377-378
+### code chunk number 23: BoolNet_package_vignette.Snw:367-368
 ###################################################
 net <- generateRandomNKNetwork(n=20, k=20, topology="scale_free")
 
 
 ###################################################
-### code chunk number 26: BoolNet_package_vignette.Snw:382-383
+### code chunk number 24: BoolNet_package_vignette.Snw:372-373
 ###################################################
 net <- generateRandomNKNetwork(n=10, k=3, linkage="lattice")
 
 
 ###################################################
-### code chunk number 27: BoolNet_package_vignette.Snw:388-392
+### code chunk number 25: BoolNet_package_vignette.Snw:378-382
 ###################################################
 net <- generateRandomNKNetwork(n=10, 
                                k=3, 
@@ -197,7 +179,7 @@ net <- generateRandomNKNetwork(n=10,
 
 
 ###################################################
-### code chunk number 28: BoolNet_package_vignette.Snw:399-407
+### code chunk number 26: BoolNet_package_vignette.Snw:389-397
 ###################################################
 net1 <- generateRandomNKNetwork(n=10, 
                                 k=3,
@@ -210,7 +192,7 @@ net2 <- generateRandomNKNetwork(n=10,
 
 
 ###################################################
-### code chunk number 29: BoolNet_package_vignette.Snw:415-428
+### code chunk number 27: BoolNet_package_vignette.Snw:405-418
 ###################################################
 isMonotone <- function(input, func)
 {
@@ -228,7 +210,7 @@ isMonotone <- function(input, func)
 
 
 ###################################################
-### code chunk number 30: BoolNet_package_vignette.Snw:437-441
+### code chunk number 28: BoolNet_package_vignette.Snw:427-431
 ###################################################
 net <- generateRandomNKNetwork(n=10,
                                k=3, 
@@ -237,101 +219,90 @@ net <- generateRandomNKNetwork(n=10,
 
 
 ###################################################
-### code chunk number 31: BoolNet_package_vignette.Snw:452-454
+### code chunk number 29: BoolNet_package_vignette.Snw:442-444
 ###################################################
 data(cellcycle)
 knockedOut <- fixGenes(cellcycle, "CycD", 0)
 
 
 ###################################################
-### code chunk number 32: BoolNet_package_vignette.Snw:457-458
+### code chunk number 30: BoolNet_package_vignette.Snw:447-448
 ###################################################
 knockedOut <- fixGenes(cellcycle, 1, 0)
 
 
 ###################################################
-### code chunk number 33: BoolNet_package_vignette.Snw:461-462
+### code chunk number 31: BoolNet_package_vignette.Snw:451-452
 ###################################################
 overExpressed <- fixGenes(cellcycle, "CycD", 1)
 
 
 ###################################################
-### code chunk number 34: BoolNet_package_vignette.Snw:465-466
+### code chunk number 32: BoolNet_package_vignette.Snw:455-456
 ###################################################
 originalNet <- fixGenes(knockedOut, "CycD", -1)
 
 
 ###################################################
-### code chunk number 35: BoolNet_package_vignette.Snw:471-472
+### code chunk number 33: BoolNet_package_vignette.Snw:461-462
 ###################################################
 newNet <- fixGenes(cellcycle, c("CycD","CycE"), c(0,1))
 
 
 ###################################################
-### code chunk number 36: BoolNet_package_vignette.Snw:483-485
+### code chunk number 34: BoolNet_package_vignette.Snw:473-475
 ###################################################
 data(cellcycle)
 stateTransition(cellcycle, rep(1,10))
 
 
 ###################################################
-### code chunk number 37: BoolNet_package_vignette.Snw:489-491
+### code chunk number 35: BoolNet_package_vignette.Snw:479-481
 ###################################################
 path <- getPathToAttractor(cellcycle, rep(0,10))
 path
 
 
 ###################################################
-### code chunk number 38: BoolNet_package_vignette.Snw:496-501
+### code chunk number 36: BoolNet_package_vignette.Snw:486-487 (eval = FALSE)
 ###################################################
-pdf("sequence.pdf")
-par(mar = c(1, 4, 2, 1))
-path <- getPathToAttractor(cellcycle, rep(0,10))
-plotSequence(sequence=path)
-dev.off()
-
-
-###################################################
-### code chunk number 39: BoolNet_package_vignette.Snw:503-505 (eval = FALSE)
-###################################################
-## path <- getPathToAttractor(cellcycle, rep(0,10))
 ## plotSequence(sequence=path)
 
 
 ###################################################
-### code chunk number 40: BoolNet_package_vignette.Snw:518-519 (eval = FALSE)
+### code chunk number 37: BoolNet_package_vignette.Snw:500-501 (eval = FALSE)
 ###################################################
 ## sequenceToLaTeX(sequence=path, file="sequence.tex")
 
 
 ###################################################
-### code chunk number 41: BoolNet_package_vignette.Snw:524-526
+### code chunk number 38: BoolNet_package_vignette.Snw:506-508
 ###################################################
 startState <- generateState(cellcycle, specs=c("CycD"=1,"CycA"=1))
 stateTransition(cellcycle,startState)
 
 
 ###################################################
-### code chunk number 42: BoolNet_package_vignette.Snw:533-534
+### code chunk number 39: BoolNet_package_vignette.Snw:515-516
 ###################################################
 data(igf)
 
 
 ###################################################
-### code chunk number 43: BoolNet_package_vignette.Snw:539-541
+### code chunk number 40: BoolNet_package_vignette.Snw:521-523
 ###################################################
 startState <- generateState(igf, specs=c("IGF"=1))
 stateTransition(igf, startState)
 
 
 ###################################################
-### code chunk number 44: BoolNet_package_vignette.Snw:544-545
+### code chunk number 41: BoolNet_package_vignette.Snw:526-527
 ###################################################
 getPathToAttractor(network=igf,state=startState)
 
 
 ###################################################
-### code chunk number 45: BoolNet_package_vignette.Snw:550-553
+### code chunk number 42: BoolNet_package_vignette.Snw:532-535
 ###################################################
 startState <- generateState(igf, specs=list("IGF"=c(0,0,1)))
 
@@ -339,74 +310,65 @@ startState
 
 
 ###################################################
-### code chunk number 46: BoolNet_package_vignette.Snw:563-567
-###################################################
-pdf("sequence_igf.pdf")
-par(mar = c(1, 9, 2, 1))
-plotSequence(network=igf, startState=startState)
-dev.off()
-
-
-###################################################
-### code chunk number 47: BoolNet_package_vignette.Snw:569-570 (eval = FALSE)
+### code chunk number 43: BoolNet_package_vignette.Snw:545-546 (eval = FALSE)
 ###################################################
 ## plotSequence(network=igf, startState=startState)
 
 
 ###################################################
-### code chunk number 48: BoolNet_package_vignette.Snw:576-577
+### code chunk number 44: BoolNet_package_vignette.Snw:552-553
 ###################################################
 set.seed(54321)
 
 
 ###################################################
-### code chunk number 49: BoolNet_package_vignette.Snw:579-580
+### code chunk number 45: BoolNet_package_vignette.Snw:555-556
 ###################################################
 stateTransition(cellcycle, rep(1,10), type="asynchronous")
 
 
 ###################################################
-### code chunk number 50: BoolNet_package_vignette.Snw:586-587
+### code chunk number 46: BoolNet_package_vignette.Snw:562-563
 ###################################################
 set.seed(4321)
 
 
 ###################################################
-### code chunk number 51: BoolNet_package_vignette.Snw:589-591
+### code chunk number 47: BoolNet_package_vignette.Snw:565-567
 ###################################################
 stateTransition(cellcycle, rep(1,10), type="asynchronous", 
 geneProbabilities=c(0.05,0.05,0.2,0.3,0.05,0.05,0.05,0.05,0.1,0.1))
 
 
 ###################################################
-### code chunk number 52: BoolNet_package_vignette.Snw:598-600
+### code chunk number 48: BoolNet_package_vignette.Snw:574-576
 ###################################################
 stateTransition(cellcycle, rep(1,10), type="asynchronous", 
 chosenGene="CycE")
 
 
 ###################################################
-### code chunk number 53: BoolNet_package_vignette.Snw:604-605
+### code chunk number 49: BoolNet_package_vignette.Snw:580-581
 ###################################################
 set.seed(432)
 
 
 ###################################################
-### code chunk number 54: BoolNet_package_vignette.Snw:607-609
+### code chunk number 50: BoolNet_package_vignette.Snw:583-585
 ###################################################
 data(examplePBN)
 stateTransition(examplePBN, c(0,1,1), type="probabilistic")
 
 
 ###################################################
-### code chunk number 55: BoolNet_package_vignette.Snw:612-614
+### code chunk number 51: BoolNet_package_vignette.Snw:588-590
 ###################################################
 stateTransition(examplePBN, c(0,1,1), type="probabilistic", 
 chosenFunctions=c(2,1,2))
 
 
 ###################################################
-### code chunk number 56: BoolNet_package_vignette.Snw:632-635 (eval = FALSE)
+### code chunk number 52: BoolNet_package_vignette.Snw:608-611 (eval = FALSE)
 ###################################################
 ## data(cellcycle)
 ## attr <- getAttractors(cellcycle)
@@ -414,145 +376,89 @@ chosenFunctions=c(2,1,2))
 
 
 ###################################################
-### code chunk number 57: BoolNet_package_vignette.Snw:638-640
+### code chunk number 53: BoolNet_package_vignette.Snw:614-616
 ###################################################
 attr <- getAttractors(cellcycle)
 attr
 
 
 ###################################################
-### code chunk number 58: BoolNet_package_vignette.Snw:646-647 (eval = FALSE)
+### code chunk number 54: BoolNet_package_vignette.Snw:622-623 (eval = FALSE)
 ###################################################
 ## print(attr, activeOnly=TRUE)
 
 
 ###################################################
-### code chunk number 59: BoolNet_package_vignette.Snw:650-651
+### code chunk number 55: BoolNet_package_vignette.Snw:626-627
 ###################################################
 print(attr, activeOnly=TRUE)
 
 
 ###################################################
-### code chunk number 60: BoolNet_package_vignette.Snw:660-661
+### code chunk number 56: BoolNet_package_vignette.Snw:636-637
 ###################################################
 getAttractorSequence(attr, 2)
 
 
 ###################################################
-### code chunk number 61: BoolNet_package_vignette.Snw:673-674 (eval = FALSE)
-###################################################
-## plotAttractors(attr, subset=2)
-
-
-###################################################
-### code chunk number 62: BoolNet_package_vignette.Snw:676-680
-###################################################
-pdf("attractor1.pdf")
-par(mar=c(1,5,1,1))
-plotAttractors(attr, subset=2)
-dev.off()
-
-
-###################################################
-### code chunk number 63: BoolNet_package_vignette.Snw:683-684 (eval = FALSE)
-###################################################
-## attractorsToLaTeX(attr, subset=2, file="attractors.tex")
-
-
-###################################################
-### code chunk number 64: BoolNet_package_vignette.Snw:691-693 (eval = FALSE)
+### code chunk number 57: BoolNet_package_vignette.Snw:644-646 (eval = FALSE)
 ###################################################
 ## tt <- getTransitionTable(attr)
 ## tt
 
 
 ###################################################
-### code chunk number 65: BoolNet_package_vignette.Snw:707-708 (eval = FALSE)
+### code chunk number 58: BoolNet_package_vignette.Snw:660-661 (eval = FALSE)
 ###################################################
 ## getBasinOfAttraction(attr, 1)
 
 
 ###################################################
-### code chunk number 66: BoolNet_package_vignette.Snw:713-714 (eval = FALSE)
+### code chunk number 59: BoolNet_package_vignette.Snw:666-667 (eval = FALSE)
 ###################################################
 ## getStateSummary(attr, c(1,1,1,1,1,1,1,1,1,1))
 
 
 ###################################################
-### code chunk number 67: BoolNet_package_vignette.Snw:726-731
-###################################################
-pdf("stategraph1.pdf")
-set.seed(43210)
-par(mar=c(1,1,1,1))
-plotStateGraph(attr)
-dev.off()
-
-
-###################################################
-### code chunk number 68: BoolNet_package_vignette.Snw:733-734 (eval = FALSE)
+### code chunk number 60: BoolNet_package_vignette.Snw:679-680 (eval = FALSE)
 ###################################################
 ## plotStateGraph(attr)
 
 
 ###################################################
-### code chunk number 69: BoolNet_package_vignette.Snw:740-745
-###################################################
-pdf("piecewisestategraph.pdf")
-set.seed(43210)
-par(mar=c(1,1,1,1))
-plotStateGraph(attr, piecewise=TRUE)
-dev.off()
-
-
-###################################################
-### code chunk number 70: BoolNet_package_vignette.Snw:747-748 (eval = FALSE)
+### code chunk number 61: BoolNet_package_vignette.Snw:686-687 (eval = FALSE)
 ###################################################
 ## plotStateGraph(attr, piecewise=TRUE)
 
 
 ###################################################
-### code chunk number 71: BoolNet_package_vignette.Snw:772-773
+### code chunk number 62: BoolNet_package_vignette.Snw:702-703 (eval = FALSE)
 ###################################################
-attr <- getAttractors(cellcycle, method="random", startStates=100)
+## attr <- getAttractors(cellcycle, method="random", startStates=100)
 
 
 ###################################################
-### code chunk number 72: BoolNet_package_vignette.Snw:777-780
+### code chunk number 63: BoolNet_package_vignette.Snw:707-710 (eval = FALSE)
 ###################################################
-attr <- getAttractors(cellcycle, 
-                      method="chosen", 
-                      startStates=list(rep(0,10),rep(1,10)))
+## attr <- getAttractors(cellcycle, 
+##                       method="chosen", 
+##                       startStates=list(rep(0,10),rep(1,10)))
 
 
 ###################################################
-### code chunk number 73: BoolNet_package_vignette.Snw:789-791
+### code chunk number 64: BoolNet_package_vignette.Snw:719-720 (eval = FALSE)
 ###################################################
-attr <- getAttractors(cellcycle, 
-                      method="sat.exhaustive")
+## plotAttractors(attr, subset=2)
 
 
 ###################################################
-### code chunk number 74: BoolNet_package_vignette.Snw:796-799
+### code chunk number 65: BoolNet_package_vignette.Snw:723-724 (eval = FALSE)
 ###################################################
-attr <- getAttractors(cellcycle, 
-                      method="sat.restricted",
-                      maxAttractorLength=1)
+## attractorsToLaTeX(attr, subset=2, file="attractors.tex")
 
 
 ###################################################
-### code chunk number 75: BoolNet_package_vignette.Snw:802-803 (eval = FALSE)
-###################################################
-## attr
-
-
-###################################################
-### code chunk number 76: BoolNet_package_vignette.Snw:806-807
-###################################################
-attr
-
-
-###################################################
-### code chunk number 77: BoolNet_package_vignette.Snw:815-819
+### code chunk number 66: BoolNet_package_vignette.Snw:738-742
 ###################################################
 attr <- getAttractors(cellcycle, 
                       type="asynchronous",
@@ -561,13 +467,13 @@ attr <- getAttractors(cellcycle,
 
 
 ###################################################
-### code chunk number 78: BoolNet_package_vignette.Snw:825-826 (eval = FALSE)
+### code chunk number 67: BoolNet_package_vignette.Snw:748-749 (eval = FALSE)
 ###################################################
 ## attr
 
 
 ###################################################
-### code chunk number 79: BoolNet_package_vignette.Snw:852-857 (eval = FALSE)
+### code chunk number 68: BoolNet_package_vignette.Snw:775-780 (eval = FALSE)
 ###################################################
 ## attr <- getAttractors(cellcycle, 
 ##                       type="asynchronous",
@@ -577,91 +483,57 @@ attr <- getAttractors(cellcycle,
 
 
 ###################################################
-### code chunk number 80: BoolNet_package_vignette.Snw:872-876
-###################################################
-pdf("attractor2.pdf")
-par(mar=c(1,1,1,1))
-plotAttractors(attr, subset=2, mode="graph", drawLabels=FALSE)
-dev.off()
-
-
-###################################################
-### code chunk number 81: BoolNet_package_vignette.Snw:878-879 (eval = FALSE)
+### code chunk number 69: BoolNet_package_vignette.Snw:795-796 (eval = FALSE)
 ###################################################
 ## plotAttractors(attr, subset=2, mode="graph", drawLabels=FALSE)
 
 
 ###################################################
-### code chunk number 82: BoolNet_package_vignette.Snw:887-889 (eval = FALSE)
+### code chunk number 70: BoolNet_package_vignette.Snw:804-806 (eval = FALSE)
 ###################################################
 ## sim <- simulateSymbolicModel(igf)
 ## sim
 
 
 ###################################################
-### code chunk number 83: BoolNet_package_vignette.Snw:892-894
+### code chunk number 71: BoolNet_package_vignette.Snw:809-811
 ###################################################
 sim <- simulateSymbolicModel(igf)
 sim
 
 
 ###################################################
-### code chunk number 84: BoolNet_package_vignette.Snw:908-916
-###################################################
-pdf("attractor3.pdf")
-par(mar=c(1,5,1,1))
-plotAttractors(sim, subset=2)
-dev.off()
-pdf("stategraph2.pdf")
-par(mar=c(1,1,1,1))
-plotStateGraph(sim)
-dev.off()
-
-
-###################################################
-### code chunk number 85: BoolNet_package_vignette.Snw:918-919 (eval = FALSE)
+### code chunk number 72: BoolNet_package_vignette.Snw:825-826 (eval = FALSE)
 ###################################################
 ## plotAttractors(sim, subset=2)
 
 
 ###################################################
-### code chunk number 86: BoolNet_package_vignette.Snw:922-923 (eval = FALSE)
+### code chunk number 73: BoolNet_package_vignette.Snw:829-830 (eval = FALSE)
 ###################################################
 ## plotStateGraph(sim)
 
 
 ###################################################
-### code chunk number 87: BoolNet_package_vignette.Snw:939-940
+### code chunk number 74: BoolNet_package_vignette.Snw:844-845
 ###################################################
 set.seed(43851)
 
 
 ###################################################
-### code chunk number 88: BoolNet_package_vignette.Snw:942-943
+### code chunk number 75: BoolNet_package_vignette.Snw:847-848
 ###################################################
 sim <- simulateSymbolicModel(igf, method="random", startStates=2)
 
 
 ###################################################
-### code chunk number 89: BoolNet_package_vignette.Snw:946-947
+### code chunk number 76: BoolNet_package_vignette.Snw:851-852
 ###################################################
 sim$sequences
 
 
 ###################################################
-### code chunk number 90: BoolNet_package_vignette.Snw:952-953
-###################################################
-sim <- simulateSymbolicModel(igf, method="sat.exhaustive")
-
-
-###################################################
-### code chunk number 91: BoolNet_package_vignette.Snw:956-957
-###################################################
-sim <- simulateSymbolicModel(igf, method="sat.restricted", maxAttractorLength=1)
-
-
-###################################################
-### code chunk number 92: BoolNet_package_vignette.Snw:973-976
+### code chunk number 77: BoolNet_package_vignette.Snw:867-870
 ###################################################
 data(examplePBN)
 sim <- markovSimulation(examplePBN)
@@ -669,23 +541,13 @@ sim
 
 
 ###################################################
-### code chunk number 93: BoolNet_package_vignette.Snw:982-983 (eval = FALSE)
+### code chunk number 78: BoolNet_package_vignette.Snw:876-877 (eval = FALSE)
 ###################################################
 ## plotPBNTransitions(sim)
 
 
 ###################################################
-### code chunk number 94: BoolNet_package_vignette.Snw:985-990
-###################################################
-pdf("pbntransitions.pdf")
-set.seed(4961)
-par(mar=c(1,1,1,1))
-plotPBNTransitions(sim)
-dev.off()
-
-
-###################################################
-### code chunk number 95: BoolNet_package_vignette.Snw:1003-1008
+### code chunk number 79: BoolNet_package_vignette.Snw:890-895
 ###################################################
 data(cellcycle)
 sim <- markovSimulation(cellcycle, 
@@ -695,7 +557,7 @@ sim
 
 
 ###################################################
-### code chunk number 96: BoolNet_package_vignette.Snw:1017-1022
+### code chunk number 80: BoolNet_package_vignette.Snw:904-909
 ###################################################
 sim <- markovSimulation(cellcycle, 
                         numIterations=1024,
@@ -705,13 +567,13 @@ sim
 
 
 ###################################################
-### code chunk number 97: BoolNet_package_vignette.Snw:1034-1035
+### code chunk number 81: BoolNet_package_vignette.Snw:921-922
 ###################################################
 set.seed(3361)
 
 
 ###################################################
-### code chunk number 98: BoolNet_package_vignette.Snw:1037-1042
+### code chunk number 82: BoolNet_package_vignette.Snw:924-929
 ###################################################
 data(cellcycle)
 r <- perturbTrajectories(cellcycle, 
@@ -721,29 +583,24 @@ r <- perturbTrajectories(cellcycle,
 
 
 ###################################################
-### code chunk number 99: BoolNet_package_vignette.Snw:1046-1047
+### code chunk number 83: BoolNet_package_vignette.Snw:933-934
 ###################################################
 r$value
 
 
 ###################################################
-### code chunk number 100: BoolNet_package_vignette.Snw:1051-1056
+### code chunk number 84: BoolNet_package_vignette.Snw:938-944
 ###################################################
 r <- perturbTrajectories(cellcycle, 
                          measure="sensitivity", 
                          numSamples=100, 
                          flipBits=1, 
                          gene="CycE")
-
-
-###################################################
-### code chunk number 101: BoolNet_package_vignette.Snw:1058-1059
-###################################################
 r$value
 
 
 ###################################################
-### code chunk number 102: BoolNet_package_vignette.Snw:1064-1069
+### code chunk number 85: BoolNet_package_vignette.Snw:949-954
 ###################################################
 r <- perturbTrajectories(cellcycle, 
                          measure="attractor", 
@@ -753,7 +610,7 @@ r$value
 
 
 ###################################################
-### code chunk number 103: BoolNet_package_vignette.Snw:1076-1079
+### code chunk number 86: BoolNet_package_vignette.Snw:961-964
 ###################################################
 perturbedNet <- perturbNetwork(cellcycle, 
                                perturb="functions", 
@@ -761,7 +618,7 @@ perturbedNet <- perturbNetwork(cellcycle,
 
 
 ###################################################
-### code chunk number 104: BoolNet_package_vignette.Snw:1084-1087
+### code chunk number 87: BoolNet_package_vignette.Snw:969-972
 ###################################################
 perturbedNet <- perturbNetwork(cellcycle, 
                                perturb="functions", 
@@ -769,7 +626,7 @@ perturbedNet <- perturbNetwork(cellcycle,
 
 
 ###################################################
-### code chunk number 105: BoolNet_package_vignette.Snw:1093-1097
+### code chunk number 88: BoolNet_package_vignette.Snw:978-982
 ###################################################
 perturbedNet <- perturbNetwork(cellcycle, 
                                perturb="transitions", 
@@ -778,7 +635,7 @@ perturbedNet <- perturbNetwork(cellcycle,
 
 
 ###################################################
-### code chunk number 106: BoolNet_package_vignette.Snw:1105-1161 (eval = FALSE)
+### code chunk number 89: BoolNet_package_vignette.Snw:990-1046 (eval = FALSE)
 ###################################################
 ## # Perform a robustness test on a network
 ## # by counting the numbers of perturbed networks
@@ -839,7 +696,7 @@ perturbedNet <- perturbNetwork(cellcycle,
 
 
 ###################################################
-### code chunk number 107: BoolNet_package_vignette.Snw:1195-1200 (eval = FALSE)
+### code chunk number 90: BoolNet_package_vignette.Snw:1080-1085 (eval = FALSE)
 ###################################################
 ## data(cellcycle)
 ## res <- testNetworkProperties(cellcycle, 
@@ -849,21 +706,7 @@ perturbedNet <- perturbNetwork(cellcycle,
 
 
 ###################################################
-### code chunk number 108: BoolNet_package_vignette.Snw:1206-1215
-###################################################
-pdf("attractor_robustness.pdf")
-par(mar=c(4,4,2,1))
-data(cellcycle)
-set.seed(3241)
-res <- testNetworkProperties(cellcycle, 
-                      numRandomNets=100, 
-                      testFunction="testAttractorRobustness", 
-                      testFunctionParams = list(copies=100, perturb="functions"))
-dev.off()
-
-
-###################################################
-### code chunk number 109: BoolNet_package_vignette.Snw:1236-1241 (eval = FALSE)
+### code chunk number 91: BoolNet_package_vignette.Snw:1109-1114 (eval = FALSE)
 ###################################################
 ## testNetworkProperties(cellcycle, 
 ##                       numRandomNets=100,
@@ -873,22 +716,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 110: BoolNet_package_vignette.Snw:1244-1254
-###################################################
-pdf("transition_robustness.pdf")
-par(mar=c(4,4,2,1))
-data(cellcycle)
-set.seed(22652)
-testNetworkProperties(cellcycle, 
-                      numRandomNets=100,
-                      testFunction="testTransitionRobustness",
-                      testFunctionParams=list(numSamples=100),
-                      alternative="less")  
-dev.off()
-
-
-###################################################
-### code chunk number 111: BoolNet_package_vignette.Snw:1259-1262 (eval = FALSE)
+### code chunk number 92: BoolNet_package_vignette.Snw:1121-1124 (eval = FALSE)
 ###################################################
 ## testNetworkProperties(cellcycle, 
 ##                       numRandomNets=100, 
@@ -896,19 +724,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 112: BoolNet_package_vignette.Snw:1264-1271
-###################################################
-pdf("indegree.pdf")
-par(mar=c(4,4,2,1))
-set.seed(6314)
-testNetworkProperties(cellcycle, 
-                      numRandomNets=100, 
-                      testFunction="testIndegree")
-dev.off()
-
-
-###################################################
-### code chunk number 113: BoolNet_package_vignette.Snw:1288-1292 (eval = FALSE)
+### code chunk number 93: BoolNet_package_vignette.Snw:1142-1146 (eval = FALSE)
 ###################################################
 ## testNetworkProperties(cellcycle, 
 ##                       numRandomNets=100, 
@@ -917,20 +733,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 114: BoolNet_package_vignette.Snw:1294-1302
-###################################################
-pdf("indegree_kl.pdf")
-par(mar=c(4,4,2,1))
-set.seed(234256)
-testNetworkProperties(cellcycle, 
-                      numRandomNets=100, 
-                      testFunction="testIndegree", 
-                      accumulation="kullback_leibler")
-dev.off()
-
-
-###################################################
-### code chunk number 115: BoolNet_package_vignette.Snw:1318-1330
+### code chunk number 94: BoolNet_package_vignette.Snw:1162-1174
 ###################################################
 testBasinSizes <- function(network, accumulate=TRUE, params)
 {
@@ -947,7 +750,7 @@ testBasinSizes <- function(network, accumulate=TRUE, params)
 
 
 ###################################################
-### code chunk number 116: BoolNet_package_vignette.Snw:1336-1340 (eval = FALSE)
+### code chunk number 95: BoolNet_package_vignette.Snw:1180-1184 (eval = FALSE)
 ###################################################
 ## testNetworkProperties(cellcycle, 
 ##                       numRandomNets=100,
@@ -956,81 +759,58 @@ testBasinSizes <- function(network, accumulate=TRUE, params)
 
 
 ###################################################
-### code chunk number 117: BoolNet_package_vignette.Snw:1342-1350
-###################################################
-pdf("basinsize.pdf")
-par(mar=c(4,4,2,1))
-set.seed(6724)
-testNetworkProperties(cellcycle, 
-                      numRandomNets=100,
-                      testFunction="testBasinSizes",
-                      xlab="Average size of basins of attraction")
-dev.off()
-
-
-###################################################
-### code chunk number 118: BoolNet_package_vignette.Snw:1373-1374 (eval = FALSE)
+### code chunk number 96: BoolNet_package_vignette.Snw:1207-1208 (eval = FALSE)
 ###################################################
 ## saveNetwork(cellcycle, file="cellcycle.txt")
 
 
 ###################################################
-### code chunk number 119: BoolNet_package_vignette.Snw:1379-1381
+### code chunk number 97: BoolNet_package_vignette.Snw:1213-1215
 ###################################################
 net <- generateRandomNKNetwork(n=10, k=3, readableFunctions=FALSE)
 saveNetwork(net, file="randomnet.txt", generateDNF=TRUE)
 
 
 ###################################################
-### code chunk number 120: BoolNet_package_vignette.Snw:1396-1399
+### code chunk number 98: BoolNet_package_vignette.Snw:1230-1233 (eval = FALSE)
 ###################################################
-toSBML(cellcycle, file="cellcycle.sbml")
-sbml_cellcycle <- loadSBML("cellcycle.sbml")
-sbml_cellcycle
+## toSBML(cellcycle, file="cellcycle.sbml")
+## sbml_cellcycle <- loadSBML("cellcycle.sbml")
+## sbml_cellcycle
 
 
 ###################################################
-### code chunk number 121: BoolNet_package_vignette.Snw:1418-1419 (eval = FALSE)
+### code chunk number 99: BoolNet_package_vignette.Snw:1252-1253 (eval = FALSE)
 ###################################################
 ## system.file("doc/example.btp", package="BoolNet")
 
 
 ###################################################
-### code chunk number 122: BoolNet_package_vignette.Snw:1451-1452
+### code chunk number 100: BoolNet_package_vignette.Snw:1285-1286
 ###################################################
 net <- loadBioTapestry(system.file("doc/example.btp", package="BoolNet"))
 
 
 ###################################################
-### code chunk number 123: BoolNet_package_vignette.Snw:1454-1455 (eval = FALSE)
+### code chunk number 101: BoolNet_package_vignette.Snw:1288-1289 (eval = FALSE)
 ###################################################
 ## net <- loadBioTapestry("example.btp")
 
 
 ###################################################
-### code chunk number 124: BoolNet_package_vignette.Snw:1460-1461 (eval = FALSE)
+### code chunk number 102: BoolNet_package_vignette.Snw:1294-1295 (eval = FALSE)
 ###################################################
 ## net
 
 
 ###################################################
-### code chunk number 125: BoolNet_package_vignette.Snw:1484-1485 (eval = FALSE)
+### code chunk number 103: BoolNet_package_vignette.Snw:1318-1319 (eval = FALSE)
 ###################################################
 ## plotNetworkWiring(net)
 
 
 ###################################################
-### code chunk number 126: BoolNet_package_vignette.Snw:1487-1492
-###################################################
-pdf("wiring_biotap.pdf")
-par(mar=c(1,1,1,1))
-set.seed(559652)
-plotNetworkWiring(net)
-dev.off()
-
-
-###################################################
-### code chunk number 127: BoolNet_package_vignette.Snw:1513-1516 (eval = FALSE)
+### code chunk number 104: BoolNet_package_vignette.Snw:1340-1343 (eval = FALSE)
 ###################################################
 ## data(cellcycle)
 ## attr <- getAttractors(cellcycle)
@@ -1038,7 +818,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 128: BoolNet_package_vignette.Snw:1520-1521 (eval = FALSE)
+### code chunk number 105: BoolNet_package_vignette.Snw:1347-1348 (eval = FALSE)
 ###################################################
 ## toPajek(attr, file="cellcycle.net", includeLabels=TRUE)
 
