@@ -341,7 +341,7 @@ TemporalAttractorStateListElement * getAttractorForState(
 /**
  * Allocate a list structure that stores attractors
  */
-TemporalAttractorStateList * allocAttractorStateList()
+TemporalAttractorStateList * allocAttractorStateList(void)
 {
 	TemporalAttractorStateList * res = CALLOC(1,
 			sizeof(TemporalAttractorStateList));
@@ -885,8 +885,8 @@ SEXP symbolicSATSearch_R(SEXP network, SEXP maxAttractorSize,
 		el = el->next;
 	}
 	SETCADDR(retSXP, attractorListSXP);
-	UNPROTECT(2);
-	PutRNGstate();
+    PutRNGstate();
+    UNPROTECT(2);
 	return (retSXP);
 }
 
